@@ -9,7 +9,6 @@ except ImportError:  # pragma: no cover
 
 
 if _lzma:
-
     from .abc import Codec
     from .compat import ndarray_copy, ensure_contiguous_ndarray
 
@@ -42,16 +41,19 @@ if _lzma:
             self.filters = filters
 
         def encode(self, buf):
-
             # normalise inputs
             buf = ensure_contiguous_ndarray(buf)
 
             # do compression
-            return _lzma.compress(buf, format=self.format, check=self.check,
-                                  preset=self.preset, filters=self.filters)
+            return _lzma.compress(
+                buf,
+                format=self.format,
+                check=self.check,
+                preset=self.preset,
+                filters=self.filters,
+            )
 
         def decode(self, buf, out=None):
-
             # normalise inputs
             buf = ensure_contiguous_ndarray(buf)
             if out is not None:
@@ -64,7 +66,11 @@ if _lzma:
             return ndarray_copy(dec, out)
 
         def __repr__(self):
-            r = '%s(format=%r, check=%r, preset=%r, filters=%r)' % \
-                (type(self).__name__, self.format, self.check, self.preset,
-                 self.filters)
+            r = '%s(format=%r, check=%r, preset=%r, filters=%r)' % (
+                type(self).__name__,
+                self.format,
+                self.check,
+                self.preset,
+                self.filters,
+            )
             return r
