@@ -49,8 +49,7 @@ class Pickle(Codec):
             return dec
 
     def get_config(self):
-        return dict(id=self.codec_id,
-                    protocol=self.protocol)
+        return dict(id=self.codec_id, protocol=self.protocol)
 
     def __repr__(self):
         return 'Pickle(protocol=%s)' % self.protocol
