@@ -7,7 +7,6 @@ import numcodecs.registry
 
 
 here = os.path.abspath(os.path.dirname(__file__))
-pytest.importorskip("entrypoints")
 
 
 @pytest.fixture()
@@ -20,7 +19,7 @@ def set_path():
     numcodecs.registry.codec_registry.pop("test")
 
 
-@pytest.mark.xfail(reason="FIXME: not working in wheels build")
-def test_entrypoint_codec(set_path):
+@pytest.mark.usefixtures("set_path")
+def test_entrypoint_codec():
     cls = numcodecs.registry.get_codec({"id": "test"})
     assert cls.codec_id == "test"
