@@ -7,8 +7,12 @@ import pytest
 
 
 from numcodecs.fixedscaleoffset import FixedScaleOffset
-from numcodecs.tests.common import (check_encode_decode, check_config, check_repr,
-                                    check_backwards_compatibility)
+from numcodecs.tests.common import (
+    check_encode_decode,
+    check_config,
+    check_repr,
+    check_backwards_compatibility,
+)
 
 
 arrays = [
